<?php
/***************************************\
|			PHP OPTIMISATEUR			|
|		Fichier de configuration		|
\***************************************/


### REPERTOIRES ###
// Repertoire source (avec slash final)
$DIRsource = './in/'; 		
// Repertoire de sortie (avec slash final)
$DIRsortie = './out/'; 	


### OPTIONS ###
// Mode silencieux, si activé aucune info ne sera affichée et le dossier de sortie sera automatiquement vidé
$silentORNOT = false; 		
// Créer le repertoire 'pwg_high'
$DIRhighORNOT = true; 		
// Redimensionner les images haute définition
$DIMhdORNOT = false; 		
// Renommer les fichiers pour enlever les caractères spéciaux
$renameORNOT = true; 		
// Ajouter un fichier 'index.php' dans chaque sous répertoire
$indexORNOT = true; 		
// Préfixe des miniatures
$prefixe_mini = 'TN-'; 		


### RESOLUTIONS ###
// Taille maximale des images HD en pixels
$DIMhd = 2560; 				
// Taille maximale des images normales en pixels
$DIMnormal = 800; 			
// Taille maximale des miniatures en pixels
$DIMthumbnail = 120; 		
// Qualité des images hd en pourcentage
$Qhd = 100; 				
// Qualité des images normales en pourcentage
$Qnormal = 80; 				
// Qualité des miniatures en pourcentage
$Qthumbnail = 80; 			
// Résolution des images (uniquement pour les images HD, les autres sont en 72 dpi - résolution web), ne fonctionne que si DIMhdORNOT est activé
$DPI = 72;					


### COPYRIGHT ###
// [alt]0169 pour le symbole ©
$copyright = '© 2010';		
// Activer le copyright sur les images HD, ne fonctionne que si DIMhdORNOT est activé
$copyONhd = false; 			
// Activer le copyright sur les images normales
$copyONnormal = false; 		
// Position du copyright : top-left, top-center, top-right, center-left, center, center-right, bottom-left, bottom-center, bottom-right
$copyPOS = 'bottom-right'; 	
// Ratio hauteur image/hauteur texte
$copySIZE = 0.05; 			
// Couleur au format RGB
$copyCOLOR = '0 0 0'; 		
// Police utilisée, elle doit être installée sur votre machine
$copyFONT = 'Arial'; 		


### PLUGINS ###
// Plugins lancés avant execution
$PluginsBefore = array( 	
	'create_folders_alpha' => array(
		'active' => false
	),
	'watermark' => array(
		'active' => false, 
		'waterFILE' => 'logo.png', 	// Fichier a incruster
		'waterALPHA' => 80, 		// Opacité
	),
);

// Plugins lancés pendant l'execution
$PluginsProcess = array( 	
	'convert_pan' => array(
		'active' => false, 
		'DIMpanorama' => 500, 		// Hauteur des images normales pour les panoramas
		'NAMEpanorama' => '_pan', 	// Suffixe des panoramas
		'RatioPanThumb' => 1.7, 	// Ratio pour les miniatures
	),
	'front2back_support' => array(
		'active' => false, 
		'NAMEverso' => '_verso', 	// Suffixe des images alternatives
		'MOVEverso' => true,		// Déplacer les images originales dans un sous dosssier 'verso'
	),
);

// Plugins lancés après execution
$PluginsAfter = array( 		
);



### NE PAS MODIFIER ###
if (!$silentORNOT) {
	function bool_to_string($bool) {
		if (is_bool($bool)) {
			if ($bool) return 'oui';
			else return 'non';
		} else {
			return $bool;
		}
	}
	
	echo '<div class="config">
		<h2>Configuration</h2>
		<ul>
			<li>
				<b>Répertoires</b>
				<ul>
					<li><b>Répertoire source :</b> '.$DIRsource.'</li>
					<li><b>Répertoire de sortie :</b> '.$DIRsortie.'</li>
				</ul>
			</li>
			<li>
				<b>Options</b>
				<ul>
					<li><b>Créer le dossier haute définition :</b> '.bool_to_string($DIRhighORNOT).'</li>
					<li><b>Redimensionner les images HD :</b> '.bool_to_string($DIMhdORNOT).'</li>
					<li><b>Renommer les fichiers :</b> '.bool_to_string($renameORNOT).'</li>
					<li><b>Ajouter les fichiers index.php :</b> '.bool_to_string($indexORNOT).'</li>
					<li><b>Préfixe des miniatures :</b> '.$prefixe_mini.'</li>
				</ul>
			</li>
			<li>
				<b>Tailles et qualité</b>
				<ul>
					<li><b>Taille maximale des images HD :</b> '.$DIMhd.'</li>
					<li><b>Taille des images normales :</b> '.$DIMnormal.'</li>
					<li><b>Taille des miniatures :</b> '.$DIMthumbnail.'</li>
					<li><b>Qualité des images HD :</b> '.$Qhd.'</li>
					<li><b>Qualité des images normales :</b> '.$Qnormal.'</li>
					<li><b>Qualité des miniatures :</b> '.$Qthumbnail.'</li>
					<li><b>Résolution (HD) :</b> '.$DPI.'</li>
				</ul>
			</li>
			<li>
				<b>Copyright</b>
				<ul>
					<li><b>Texte :</b> '.$copyright.'</li>
					<li><b>Sur les images HD :</b> '.bool_to_string($copyONhd).'</li>
					<li><b>Sur les images normales :</b> '.bool_to_string($copyONnormal).'</li>
					<li><b>Position :</b> '.$copyPOS.'</li>
					<li><b>Taille (ratio image/texte) :</b> '.$copySIZE.'</li>
					<li><b>Couleur (RGB) :</b> '.$copyCOLOR.'</li>
					<li><b>Police :</b> '.$copyFONT.'</li>
				</ul>
			</li>
			<li><b>Plugins pré-processing</b>
				<ul>';
					foreach ($PluginsBefore as $name => $config) {
						echo '<li>
							<b>'.$name.' :</b>
							<ul>';
								foreach ($config as $key => $value) {
									echo '<li>['.$key.'] => '.bool_to_string($value).'</li>';
								}
							echo '</ul>
						</li>';
					}
				echo '</ul>
			</li>
			<li><b>Plugins processing</b>
				<ul>';
					foreach ($PluginsProcess as $name => $config) {
						echo '<li>
							<b>'.$name.' :</b>
							<ul>';
								foreach ($config as $key => $value) {
									echo '<li>['.$key.'] => '.bool_to_string($value).'</li>';
								}
							echo '</ul>
						</li>';
					}
				echo '</ul>
			</li>
			<li><b>Plugins post-processing</b>
				<ul>';
					foreach ($PluginsAfter as $name => $config) {
						echo '<li>
							<b>'.$name.' :</b>
							<ul>';
								foreach ($config as $key => $value) {
									echo '<li>['.$key.'] => '.bool_to_string($value).'</li>';
								}
							echo '</ul>
						</li>';
					}
				echo '</ul>
			</li>
		</ul>
	</div>';
}
?>